/*
 * Copyright (c) 2022-present Charles7c Authors. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package top.continew.admin.business.service.Impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import top.continew.admin.business.mapper.UserMapper;
import top.continew.admin.business.model.entity.User;
import top.continew.admin.business.model.query.TgUserQuery;
import top.continew.admin.business.model.query.TgUserTeamQuery;
import top.continew.admin.business.model.req.TgUserReq;
import top.continew.admin.business.service.IUserService;
import top.continew.starter.extension.crud.model.resp.BasePageResp;
import top.continew.starter.extension.crud.model.resp.PageResp;

import java.time.LocalDateTime;
import java.util.List;

/**
 * <p>
 * tg用户 服务实现类
 * </p>
 *
 * @author xudm
 * @since 2024-12-14
 */
@Service
public class UserServiceImpl extends ServiceImpl<UserMapper, User> implements IUserService {
    @Override
    public PageResp<User> pageQuery(TgUserQuery queryVo) {
        Page<User> page = new Page<>();
        page.setCurrent(queryVo.getPage() != 0 ? queryVo.getPage() : 1);
        page.setSize(queryVo.getSize() != 0 ? queryVo.getSize() : 10);

        List<User> userOfPage = getBaseMapper().getTgUserOfPage(queryVo, page);
        page.setRecords(userOfPage);
        return PageResp.build(page, User.class);
    }

    @Override
    public void disableTgUserByIds(List<Long> ids) {
        List<User> users = listByIds(ids);
        users.forEach(u -> {
            u.setDisableFlag(1);
            u.setUpdatedTime(LocalDateTime.now());
        });
        getBaseMapper().updateById(users);
    }

    @Override
    public BasePageResp<User> getMyTeamUserListByType(TgUserTeamQuery queryVo) {
        Page<User> page = new Page<>();
        page.setCurrent(queryVo.getPage() != 0 ? queryVo.getPage() : 1);
        page.setSize(queryVo.getSize() != 0 ? queryVo.getSize() : 10);
        List<User> listByType = getBaseMapper().getMyTeamUserListByType(queryVo, page);
        page.setRecords(listByType);
        return PageResp.build(page, User.class);
    }

    @Override
    public void updateTgUserInfo(Long id, TgUserReq req) {
        User byId = getById(id);
        BeanUtils.copyProperties(req, byId);
        byId.setUpdatedTime(LocalDateTime.now());
        getBaseMapper().updateById(byId);
    }
}
